@@ -96,12 +96,16 @@ handle_extension() {
             exit 1 ;;
 
             ## OpenDocument
-        odt|ods|odp|sxw)
+        odt|sxw)
             ## Preview as text conversion
             odt2txt "${FILE_PATH}" && exit 0
             ## Preview as markdown conversion
             pandoc -s -t markdown -- "${FILE_PATH}" && exit 0
             exit 1 ;;
+        ods|odp)
+            ## Preview as text conversion (unsupported by pandoc for markdown)
+            odt2txt "${FILE_PATH}" && exit 0
+            exit 1 ;;
 
             ## XLSX
         xlsx)
