@@ -1,13 +1,19 @@
 pub mod bookmark;
 pub mod bulk_rename;
+pub mod case_sensitivity;
 pub mod change_directory;
 pub mod command_line;
 pub mod cursor_move;
+pub mod custom_search;
 pub mod delete_files;
 pub mod escape;
 pub mod file_ops;
 pub mod filter;
+pub mod filter_glob;
+pub mod filter_regex;
+pub mod filter_string;
 pub mod flat;
+pub mod fzf;
 pub mod line_nums;
 pub mod linemode;
 pub mod new_directory;
@@ -21,8 +27,13 @@ pub mod rename_file;
 pub mod search;
 pub mod search_fzf;
 pub mod search_glob;
+pub mod search_regex;
 pub mod search_string;
 pub mod select;
+pub mod select_fzf;
+pub mod select_glob;
+pub mod select_regex;
+pub mod select_string;
 pub mod set_mode;
 pub mod show_help;
 pub mod show_hidden;
