@@ -2,9 +2,9 @@ use std::io;
 use std::path;
 
 use crate::commands::{quit, reload};
-use crate::config::ProgramEntry;
+use crate::config::clean::mimetype::ProgramEntry;
 use crate::context::AppContext;
-use crate::error::{JoshutoError, JoshutoErrorKind, JoshutoResult};
+use crate::error::{AppError, AppErrorKind, AppResult};
 use crate::ui::views::DummyListener;
 use crate::ui::views::TuiTextField;
 use crate::ui::AppBackend;
@@ -18,12 +18,15 @@ use crate::MIMETYPE_T;
 fn _get_options<'a>(path: &path::Path) -> Vec<&'a ProgramEntry> {
     let mut options: Vec<&ProgramEntry> = Vec::new();
 
-    if let Some(file_ext) = path.extension().and_then(|ext| ext.to_str()) {
-        if let Some(entries) = MIMETYPE_T.app_list_for_ext(file_ext) {
-            options.extend(entries);
-            return options;
-        }
+    if let Some(entries) = path
+        .extension()
+        .and_then(|ext| ext.to_str())
+        .and_then(|file_ext| MIMETYPE_T.app_list_for_ext(file_ext))
+    {
+        options.extend(entries);
+        return options;
     }
+
     if let Ok(file_mimetype) = get_mimetype(path) {
         if let Some(entry) = MIMETYPE_T.app_list_for_mimetype(file_mimetype.get_type()) {
             match entry.subtypes().get(file_mimetype.get_subtype()) {
@@ -56,8 +59,9 @@ where
         context.worker_context_mut().push_child(child_id, handle);
     } else {
         backend.terminal_drop();
-        execute_and_wait(option, files)?;
+        let res = execute_and_wait(option, files);
         backend.terminal_restore()?;
+        res?;
     }
     Ok(())
 }
@@ -73,9 +77,12 @@ fn _open_with_xdg(
         open::that_in_background(path);
     } else {
         backend.terminal_drop();
-        let result = open::that(path);
+        let handle = open::that_in_background(path);
+        let result = handle.join();
         backend.terminal_restore()?;
-        result?;
+        if let Ok(result) = result {
+            result?;
+        }
     }
     Ok(())
 }
@@ -140,7 +147,7 @@ where
     Ok(())
 }
 
-pub fn open(context: &mut AppContext, backend: &mut AppBackend) -> JoshutoResult {
+pub fn open(context: &mut AppContext, backend: &mut AppBackend) -> AppResult {
     let curr_list = context.tab_context_ref().curr_tab_ref().curr_list_ref();
     let entry = curr_list.and_then(|s| s.curr_entry_ref().cloned());
 
@@ -186,7 +193,7 @@ pub fn open_with_index(
     context: &mut AppContext,
     backend: &mut AppBackend,
     index: usize,
-) -> JoshutoResult {
+) -> AppResult {
     let paths = context
         .tab_context_ref()
         .curr_tab_ref()
@@ -194,8 +201,8 @@ pub fn open_with_index(
         .map_or(vec![], |s| s.iter_selected().cloned().collect());
 
     if paths.is_empty() {
-        return Err(JoshutoError::new(
-            JoshutoErrorKind::Io(io::ErrorKind::NotFound),
+        return Err(AppError::new(
+            AppErrorKind::Io(io::ErrorKind::NotFound),
             String::from("No files selected"),
         ));
     }
@@ -203,8 +210,8 @@ pub fn open_with_index(
     let options = _get_options(paths[0].file_path());
 
     if index >= options.len() {
-        return Err(JoshutoError::new(
-            JoshutoErrorKind::Io(std::io::ErrorKind::InvalidData),
+        return Err(AppError::new(
+            AppErrorKind::Io(std::io::ErrorKind::InvalidData),
             "option does not exist".to_string(),
         ));
     }
@@ -214,7 +221,7 @@ pub fn open_with_index(
     Ok(())
 }
 
-pub fn open_with_interactive(context: &mut AppContext, backend: &mut AppBackend) -> JoshutoResult {
+pub fn open_with_interactive(context: &mut AppContext, backend: &mut AppBackend) -> AppResult {
     let mut paths = context
         .tab_context_ref()
         .curr_tab_ref()
