@@ -2,9 +2,9 @@ use std::cmp::Ordering;
 
 use termion::event::{Event, Key};
 
-use crate::config::AppKeyMapping;
+use crate::config::clean::keymap::AppKeyMapping;
 use crate::context::AppContext;
-use crate::error::JoshutoResult;
+use crate::error::AppResult;
 use crate::event::process_event;
 use crate::event::AppEvent;
 use crate::key_command::{Command, CommandKeybind};
@@ -16,7 +16,7 @@ pub fn help_loop(
     context: &mut AppContext,
     backend: &mut AppBackend,
     keymap_t: &AppKeyMapping,
-) -> JoshutoResult {
+) -> AppResult {
     context.flush_event();
 
     let mut offset = 0;
@@ -48,18 +48,28 @@ pub fn help_loop(
                         Event::Key(Key::Char('3')) => sort_by = 2,
                         Event::Key(Key::Char('/')) => search_query.push('/'),
                         event => {
-                            if let Some(CommandKeybind::SimpleKeybind(command)) =
+                            if let Some(CommandKeybind::SimpleKeybind { commands, .. }) =
                                 keymap_t.help_view.get(&event)
                             {
-                                match command {
-                                    Command::CursorMoveUp { .. } => move_offset(&mut offset, -1),
-                                    Command::CursorMoveDown { .. } => move_offset(&mut offset, 1),
-                                    Command::CursorMoveHome => offset = 0,
-                                    Command::CursorMoveEnd => offset = 255,
-                                    Command::CursorMovePageUp(_) => move_offset(&mut offset, -10),
-                                    Command::CursorMovePageDown(_) => move_offset(&mut offset, 10),
-                                    Command::CloseTab | Command::Help => break,
-                                    _ => (),
+                                for command in commands {
+                                    match command {
+                                        Command::CursorMoveUp { .. } => {
+                                            move_offset(&mut offset, -1)
+                                        }
+                                        Command::CursorMoveDown { .. } => {
+                                            move_offset(&mut offset, 1)
+                                        }
+                                        Command::CursorMoveHome => offset = 0,
+                                        Command::CursorMoveEnd => offset = 255,
+                                        Command::CursorMovePageUp(_) => {
+                                            move_offset(&mut offset, -10)
+                                        }
+                                        Command::CursorMovePageDown(_) => {
+                                            move_offset(&mut offset, 10)
+                                        }
+                                        Command::CloseTab | Command::Help => break,
+                                        _ => (),
+                                    }
                                 }
                             }
                         }
