@@ -1,10 +1,31 @@
 use crate::context::AppContext;
-use crate::error::JoshutoResult;
+use crate::error::AppResult;
 use crate::ui::AppBackend;
 use std::process::{Command, Stdio};
 
 use super::reload;
 
+pub fn current_filenames(context: &AppContext) -> Vec<&str> {
+    let mut result = Vec::new();
+    if let Some(curr_list) = context.tab_context_ref().curr_tab_ref().curr_list_ref() {
+        let mut i = 0;
+        curr_list
+            .iter_selected()
+            .map(|e| e.file_name())
+            .for_each(|file_name| {
+                result.push(file_name);
+                i += 1;
+            });
+        if i == 0 {
+            if let Some(entry) = curr_list.curr_entry_ref() {
+                result.push(entry.file_name());
+            }
+        }
+    }
+
+    result
+}
+
 fn execute_sub_process(
     context: &mut AppContext,
     words: &[String],
@@ -14,18 +35,23 @@ fn execute_sub_process(
     for word in words.iter().skip(1) {
         match (*word).as_str() {
             "%s" => {
+                current_filenames(context).into_iter().for_each(|x| {
+                    command.arg(x);
+                });
+            }
+            "%p" => {
                 if let Some(curr_list) = context.tab_context_ref().curr_tab_ref().curr_list_ref() {
                     let mut i = 0;
                     curr_list
                         .iter_selected()
-                        .map(|e| e.file_name())
-                        .for_each(|file_name| {
-                            command.arg(file_name);
+                        .map(|e| e.file_path())
+                        .for_each(|file_path| {
+                            command.arg(file_path);
                             i += 1;
                         });
                     if i == 0 {
                         if let Some(entry) = curr_list.curr_entry_ref() {
-                            command.arg(entry.file_name());
+                            command.arg(entry.file_path());
                         }
                     }
                 }
@@ -52,16 +78,16 @@ pub fn sub_process(
     backend: &mut AppBackend,
     words: &[String],
     spawn: bool,
-) -> JoshutoResult {
+) -> AppResult {
     backend.terminal_drop();
     let res = execute_sub_process(context, words, spawn);
-    reload::soft_reload_curr_tab(context)?;
+    backend.terminal_restore()?;
+    let _ = reload::soft_reload_curr_tab(context);
     context.message_queue_mut().push_info(format!(
         "{}: {}",
         if spawn { "Spawned" } else { "Finished" },
         words.join(" ")
     ));
-    backend.terminal_restore()?;
     res?;
     Ok(())
 }
