@@ -2,12 +2,12 @@ use std::path;
 
 use uuid::Uuid;
 
-use crate::config::option::NewTabMode;
+use crate::config::clean::app::display::new_tab::NewTabMode;
 use crate::context::AppContext;
-use crate::error::{JoshutoError, JoshutoErrorKind, JoshutoResult};
+use crate::error::{AppError, AppErrorKind, AppResult};
 use crate::history::DirectoryHistory;
 use crate::tab::{JoshutoTab, TabHomePage};
-use crate::util::unix;
+use crate::util::{cwd, unix};
 
 use crate::HOME_DIR;
 
@@ -16,7 +16,7 @@ use super::quit::{quit_with_action, QuitAction};
 fn _tab_switch(new_index: usize, context: &mut AppContext) -> std::io::Result<()> {
     context.tab_context_mut().index = new_index;
     let cwd = context.tab_context_ref().curr_tab_ref().cwd().to_path_buf();
-    std::env::set_current_dir(cwd.as_path())?;
+    cwd::set_current_dir(cwd.as_path())?;
 
     let entry_path = match context
         .tab_context_ref()
@@ -79,7 +79,7 @@ pub fn tab_switch(context: &mut AppContext, offset: i32) -> std::io::Result<()>
     _tab_switch(new_index, context)
 }
 
-pub fn tab_switch_index(context: &mut AppContext, new_index: usize) -> JoshutoResult {
+pub fn tab_switch_index(context: &mut AppContext, new_index: usize) -> AppResult {
     let num_tabs = context.tab_context_ref().len();
     if new_index <= num_tabs {
         _tab_switch(new_index - 1, context)?;
@@ -103,7 +103,7 @@ pub fn new_tab_home_path(context: &AppContext) -> path::PathBuf {
     }
 }
 
-pub fn new_tab(context: &mut AppContext, mode: &NewTabMode) -> JoshutoResult {
+pub fn new_tab(context: &mut AppContext, mode: &NewTabMode) -> AppResult {
     let new_tab_path = match mode {
         NewTabMode::Default => Ok(new_tab_home_path(context)),
         NewTabMode::CurrentTabDir => {
@@ -122,8 +122,8 @@ pub fn new_tab(context: &mut AppContext, mode: &NewTabMode) -> JoshutoResult {
                     }
                 })
             })
-            .ok_or(JoshutoError::new(
-                JoshutoErrorKind::InvalidParameters,
+            .ok_or(AppError::new(
+                AppErrorKind::InvalidParameters,
                 "No directory at cursor.".to_string(),
             )),
         NewTabMode::Directory(directory) => {
@@ -150,14 +150,14 @@ pub fn new_tab(context: &mut AppContext, mode: &NewTabMode) -> JoshutoResult {
         _tab_switch(new_index, context)?;
         Ok(())
     } else {
-        JoshutoResult::Err(JoshutoError::new(
-            JoshutoErrorKind::InvalidParameters,
+        AppResult::Err(AppError::new(
+            AppErrorKind::InvalidParameters,
             "Directory does not exist.".to_string(),
         ))
     }
 }
 
-pub fn close_tab(context: &mut AppContext) -> JoshutoResult {
+pub fn close_tab(context: &mut AppContext) -> AppResult {
     if context.tab_context_ref().len() <= 1 {
         let action = if context.args.change_directory {
             QuitAction::OutputCurrentDirectory
