@@ -14,7 +14,9 @@ pub struct TabContext {
 
 impl TabContext {
     pub fn new() -> Self {
-        Self::default()
+        Self {
+            ..Default::default()
+        }
     }
     pub fn len(&self) -> usize {
         self.tab_order.len()
@@ -23,6 +25,17 @@ impl TabContext {
     pub fn tab_ref(&self, id: &Uuid) -> Option<&JoshutoTab> {
         self.tabs.get(id)
     }
+
+    pub fn tab_refs_in_order(&self) -> Vec<&JoshutoTab> {
+        let mut tab_refs: Vec<&JoshutoTab> = vec![];
+        for tab_id in self.tab_order.iter() {
+            if let Some(tab_ref) = self.tab_ref(tab_id) {
+                tab_refs.push(tab_ref);
+            }
+        }
+        tab_refs
+    }
+
     pub fn tab_mut(&mut self, id: &Uuid) -> Option<&mut JoshutoTab> {
         self.tabs.get_mut(id)
     }
