@@ -1,4 +1,4 @@
-use tui::layout::Rect;
+use ratatui::layout::Rect;
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct UiContext {
