@@ -1,76 +1,76 @@
 use std::convert::From;
 use std::io;
 
-use super::JoshutoErrorKind;
+use super::AppErrorKind;
 
 #[derive(Clone, Debug)]
-pub struct JoshutoError {
-    _kind: JoshutoErrorKind,
+pub struct AppError {
+    _kind: AppErrorKind,
     _cause: String,
 }
 
 #[allow(dead_code)]
-impl JoshutoError {
-    pub fn new(_kind: JoshutoErrorKind, _cause: String) -> Self {
+impl AppError {
+    pub fn new(_kind: AppErrorKind, _cause: String) -> Self {
         Self { _kind, _cause }
     }
 
-    pub fn kind(&self) -> &JoshutoErrorKind {
+    pub fn kind(&self) -> &AppErrorKind {
         &self._kind
     }
 }
 
-impl std::fmt::Display for JoshutoError {
+impl std::fmt::Display for AppError {
     fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
         write!(f, "{}", self._cause)
     }
 }
 
-impl From<io::Error> for JoshutoError {
+impl From<io::Error> for AppError {
     fn from(err: io::Error) -> Self {
         let cause = err.to_string();
         Self {
-            _kind: JoshutoErrorKind::from(err.kind()),
+            _kind: AppErrorKind::from(err.kind()),
             _cause: cause,
         }
     }
 }
 
-impl From<globset::Error> for JoshutoError {
+impl From<globset::Error> for AppError {
     fn from(err: globset::Error) -> Self {
         let cause = err.to_string();
         Self {
-            _kind: JoshutoErrorKind::from(err.kind()),
+            _kind: AppErrorKind::from(err.kind()),
             _cause: cause,
         }
     }
 }
 
-impl From<std::env::VarError> for JoshutoError {
+impl From<regex::Error> for AppError {
+    fn from(err: regex::Error) -> Self {
+        let cause = err.to_string();
+        Self {
+            _kind: AppErrorKind::Regex,
+            _cause: cause,
+        }
+    }
+}
+
+impl From<std::env::VarError> for AppError {
     fn from(err: std::env::VarError) -> Self {
         let cause = err.to_string();
         Self {
-            _kind: JoshutoErrorKind::from(err),
+            _kind: AppErrorKind::from(err),
             _cause: cause,
         }
     }
 }
 
-impl From<trash::Error> for JoshutoError {
-    fn from(err: trash::Error) -> Self {
-        let cause = err.to_string();
-        Self {
-            _kind: JoshutoErrorKind::TrashError,
-            _cause: cause,
-        }
-    }
-}
-
-impl From<toml::de::Error> for JoshutoError {
+impl From<toml::de::Error> for AppError {
     fn from(err: toml::de::Error) -> Self {
         let cause = err.to_string();
         Self {
-            _kind: JoshutoErrorKind::from(err),
+            _kind: AppErrorKind::from(err),
             _cause: cause,
         }
     }
