@@ -12,6 +12,7 @@ use termion::input::TermRead;
 
 use uuid::Uuid;
 
+use crate::error::AppResult;
 use crate::fs::JoshutoDirList;
 use crate::io::FileOperationProgress;
 use crate::preview::preview_file::FilePreview;
@@ -24,7 +25,7 @@ pub enum AppEvent {
     // background IO worker events
     IoWorkerCreate,
     FileOperationProgress(FileOperationProgress),
-    IoWorkerResult(io::Result<FileOperationProgress>),
+    IoWorkerResult(AppResult<FileOperationProgress>),
 
     // forked process events
     ChildProcessComplete(u32),
@@ -53,7 +54,7 @@ pub struct Config {}
 pub struct Events {
     pub event_tx: mpsc::Sender<AppEvent>,
     event_rx: mpsc::Receiver<AppEvent>,
-    pub input_tx: mpsc::SyncSender<()>,
+    pub input_tx: mpsc::Sender<()>,
 }
 
 impl Events {
@@ -70,13 +71,17 @@ impl Events {
     }
 
     pub fn flush(&self) {
-        let _ = self.input_tx.send(());
+        loop {
+            if self.input_tx.send(()).is_ok() {
+                break;
+            }
+        }
     }
 }
 
 impl std::default::Default for Events {
     fn default() -> Self {
-        let (input_tx, input_rx) = mpsc::sync_channel(1);
+        let (input_tx, input_rx) = mpsc::channel();
         let (event_tx, event_rx) = mpsc::channel();
 
         // edge case that starts off the input thread
@@ -101,7 +106,8 @@ impl std::default::Default for Events {
             let stdin = io::stdin();
             let mut events = stdin.events();
 
-            while input_rx.recv().is_ok() {
+            loop {
+                let _ = input_rx.recv();
                 if let Some(Ok(event)) = events.next() {
                     let _ = event_tx2.send(AppEvent::Termion(event));
                 }
