@@ -4,8 +4,9 @@ use std::path::{Path, PathBuf};
 
 use walkdir::WalkDir;
 
-use crate::config::option::DirListDisplayOptions;
-use crate::config::option::{DisplayOption, TabDisplayOption};
+use crate::config::clean::app::display::dirlist::DirListDisplayOptions;
+use crate::config::clean::app::display::tab::TabDisplayOption;
+use crate::config::clean::app::display::DisplayOption;
 use crate::context::UiContext;
 use crate::fs::{JoshutoDirEntry, JoshutoDirList, JoshutoMetadata};
 
@@ -216,20 +217,17 @@ pub fn create_dirlist_with_history(
             None => 0,
         }
     };
-    let visual_mode_anchor_index = match history.get(path) {
-        None => None,
-        Some(dirlist) => {
-            dirlist
-                .get_visual_mode_anchor_index()
-                .map(|old_visual_mode_anchor_index| {
-                    if old_visual_mode_anchor_index < contents_len {
-                        old_visual_mode_anchor_index
-                    } else {
-                        contents_len - 1
-                    }
-                })
-        }
-    };
+    let visual_mode_anchor_index = history.get(path).and_then(|dirlist| {
+        dirlist
+            .get_visual_mode_anchor_index()
+            .map(|old_visual_mode_anchor_index| {
+                if old_visual_mode_anchor_index < contents_len {
+                    old_visual_mode_anchor_index
+                } else {
+                    contents_len - 1
+                }
+            })
+    });
 
     let metadata = JoshutoMetadata::from(path)?;
     let dirlist = JoshutoDirList::new(
