@@ -1,7 +1,13 @@
 use std::path;
 
+use crate::commands::case_sensitivity::SetType;
 use crate::commands::quit::QuitAction;
-use crate::config::option::{LineMode, LineNumberStyle, NewTabMode, SelectOption, SortType};
+use crate::commands::select::SelectOption;
+use crate::config::clean::app::display::line_mode::LineMode;
+use crate::config::clean::app::display::line_number::LineNumberStyle;
+use crate::config::clean::app::display::new_tab::NewTabMode;
+use crate::config::clean::app::display::sort_type::SortType;
+use crate::config::clean::app::search::CaseSensitivity;
 use crate::io::FileOperationOptions;
 
 #[derive(Clone, Debug)]
@@ -26,7 +32,9 @@ pub enum Command {
     CopyFiles,
     CopyFileName,
     CopyFileNameWithoutExtension,
-    CopyFilePath,
+    CopyFilePath {
+        all_selected: bool,
+    },
     CopyDirPath,
     SymlinkFiles {
         relative: bool,
@@ -38,6 +46,7 @@ pub enum Command {
     DeleteFiles {
         background: bool,
         permanently: bool,
+        noconfirm: bool,
     },
 
     CursorMoveUp {
@@ -86,6 +95,7 @@ pub enum Command {
         new_name: path::PathBuf,
     },
     RenameFileAppend,
+    RenameFileAppendBase,
     RenameFilePrepend,
     RenameFileKeepExt,
     TouchFile {
@@ -95,6 +105,9 @@ pub enum Command {
     SearchGlob {
         pattern: String,
     },
+    SearchRegex {
+        pattern: String,
+    },
     SearchString {
         pattern: String,
     },
@@ -104,10 +117,23 @@ pub enum Command {
     SearchNext,
     SearchPrev,
 
-    SelectFiles {
+    SelectGlob {
         pattern: String,
         options: SelectOption,
     },
+    SelectRegex {
+        pattern: String,
+        options: SelectOption,
+    },
+    SelectString {
+        pattern: String,
+        options: SelectOption,
+    },
+
+    SetCaseSensitivity {
+        case_sensitivity: CaseSensitivity,
+        set_type: SetType,
+    },
     SetMode,
     SubProcess {
         words: Vec<String>,
@@ -128,7 +154,13 @@ pub enum Command {
     Sort(SortType),
     SortReverse,
 
-    Filter {
+    FilterGlob {
+        pattern: String,
+    },
+    FilterRegex {
+        pattern: String,
+    },
+    FilterString {
         pattern: String,
     },
 
@@ -146,9 +178,15 @@ pub enum Command {
 
     SearchFzf,
     SubdirFzf,
+    SelectFzf {
+        options: SelectOption,
+    },
     Zoxide(String),
     ZoxideInteractive,
 
+    CustomSearch(Vec<String>),
+    CustomSearchInteractive(Vec<String>),
+
     BookmarkAdd,
     BookmarkChangeDirectory,
 }
