@@ -1,14 +1,20 @@
 use std::path;
 use std::process::{Command, Output};
+use std::sync::Mutex;
 use std::thread;
 use std::time;
 
-use tui::layout::Rect;
+use ratatui::layout::Rect;
 
 use crate::context::AppContext;
 use crate::event::AppEvent;
+use crate::lazy_static;
 use crate::ui::{views, AppBackend};
 
+lazy_static! {
+    static ref GUARD: Mutex<()> = Mutex::new(());
+}
+
 pub enum PreviewFileState {
     Loading,
     Error { message: String },
@@ -79,6 +85,7 @@ impl Background {
                     .insert(path.clone(), PreviewFileState::Loading);
 
                 let _ = thread::spawn(move || {
+                    let _locked = GUARD.lock().unwrap();
                     let file_full_path = path.as_path();
 
                     let res = Command::new(script)
