@@ -1,6 +1,7 @@
 mod backend;
 mod preview_area;
 mod rect;
+mod tab_list_builder;
 
 pub mod views;
 pub mod widgets;
@@ -8,3 +9,4 @@ pub mod widgets;
 pub use backend::*;
 pub use preview_area::*;
 pub use rect::*;
+pub use tab_list_builder::*;
