@@ -1,8 +1,8 @@
-use tui::buffer::Buffer;
-use tui::layout::Rect;
-use tui::widgets::Widget;
+use ratatui::buffer::Buffer;
+use ratatui::layout::Rect;
+use ratatui::widgets::Widget;
 
-use crate::config::option::DisplayMode;
+use crate::config::clean::app::display::DisplayMode;
 use crate::context::AppContext;
 use crate::ui::views::{TuiFolderView, TuiHSplitView};
 
