@@ -1,7 +1,7 @@
 use std::path::Path;
 use std::{io, process::Command};
 
-use crate::error::{JoshutoError, JoshutoErrorKind, JoshutoResult};
+use crate::error::{AppError, AppErrorKind, AppResult};
 
 pub struct Mimetype {
     _type: String,
@@ -25,7 +25,7 @@ impl Mimetype {
     }
 }
 
-pub fn get_mimetype(p: &Path) -> JoshutoResult<Mimetype> {
+pub fn get_mimetype(p: &Path) -> AppResult<Mimetype> {
     let res = Command::new("file")
         .arg("--mime-type")
         .arg("-Lb")
@@ -36,10 +36,7 @@ pub fn get_mimetype(p: &Path) -> JoshutoResult<Mimetype> {
     if !output.status.success() {
         let stderr_msg = String::from_utf8_lossy(&output.stderr).to_string();
 
-        let error = JoshutoError::new(
-            JoshutoErrorKind::Io(io::ErrorKind::InvalidInput),
-            stderr_msg,
-        );
+        let error = AppError::new(AppErrorKind::Io(io::ErrorKind::InvalidInput), stderr_msg);
         return Err(error);
     }
 
@@ -47,8 +44,8 @@ pub fn get_mimetype(p: &Path) -> JoshutoResult<Mimetype> {
     match stdout_msg.trim().split_once('/') {
         Some((ttype, subtype)) => Ok(Mimetype::new(ttype.to_string(), subtype.to_string())),
         None => {
-            let error = JoshutoError::new(
-                JoshutoErrorKind::Io(io::ErrorKind::InvalidInput),
+            let error = AppError::new(
+                AppErrorKind::Io(io::ErrorKind::InvalidInput),
                 "Unknown mimetype".to_string(),
             );
             Err(error)
