@@ -1,10 +1,10 @@
+pub mod cwd;
 pub mod format;
 pub mod fs;
 pub mod keyparse;
 pub mod mimetype;
 pub mod name_resolution;
 pub mod process;
-pub mod search;
 pub mod string;
 pub mod style;
 pub mod unix;
