@@ -3,7 +3,7 @@ use std::process;
 use std::sync::mpsc;
 use std::thread;
 
-use crate::config::ProgramEntry;
+use crate::config::clean::mimetype::ProgramEntry;
 use crate::event::AppEvent;
 
 pub fn fork_execute<I, S>(
@@ -23,6 +23,8 @@ where
         command.stderr(process::Stdio::null());
     }
 
+    let pwd = std::env::current_dir()?;
+    command.env("PWD", pwd);
     command.args(entry.get_args());
     command.args(paths);
 
@@ -51,6 +53,8 @@ where
         command.stderr(process::Stdio::null());
     }
 
+    let pwd = std::env::current_dir()?;
+    command.env("PWD", pwd);
     command.args(entry.get_args());
     command.args(paths);
 
